import { MockOptions } from './options';
export declare type Mock<T> = T;
export declare enum Mode {
    EXPECT = 0,
    CALL = 1
}
export declare let currentMode: Mode;
export declare const setMode: (mode: Mode) => void;
/**
 * Create a type safe mock.
 *
 * @see {@link when} Set expectations on the mock using `when`.
 *
 * @param options Configure the options for this specific mock, overriding any
 *   defaults that were set with {@link setDefaults}.
 * @param options.strictness Controls what happens when a property is accessed,
 *   or a call is made, and there are no expectations set for it.
 * @param options.concreteMatcher The matcher that will be used when one isn't specified explicitly.
 *
 * @example
 * const fn = mock<() => number>();
 *
 * when(() => fn()).thenReturn(23);
 *
 * fn() === 23;
 */
export declare const mock: <T>({ strictness, concreteMatcher, }?: MockOptions) => T;
